local Sorcerer = ...

-- Register prefab nodes (currently only one core model)
Sorcerer:registerAssetId("models/sorcerer.fbx/Prefab/sorcerer/housePart", _SorcererPrefix .. "_HOUSE_PREFAB")

local myMonument = {
    DataType = "BUILDING",
    Id = _SorcererPrefix .. "_HOUSE",
    Name = _SorcererPrefix .. "_HOUSE_NAME",
    Description = _SorcererPrefix .. "_HOUSE_DESC",
    BuildingType = "DECORATION"
}

if (foundation.getGameVersion == nil or version.cmp(foundation.getGameVersion(), "1.6") < 0) then
    Sorcerer:log("Hello World: version 1.5")
    SorcererTagBehaviorWork = "WORK_BEHAVIOR"
    myMonument.BuildingPartSetList = {
		{
			Name = _SorcererPrefix .. "_HOUSE_PARTSETLIST_NAME",
                	BuildingPartList = { _SorcererPrefix .. "_HOUSE_PART" }
                }
    } 
    _SorcererHouse1BuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
else
    Sorcerer:log("Hello World: version 1.6")
    myMonument.AssetCoreBuildingPart = _SorcererPrefix .. "_HOUSE_PART"
    SorcererTagBehaviorWork = "BEHAVIOR_WORK"
    if version.cmp(foundation.getGameVersion(), "1.6.6") < 0 then
        Sorcerer:log("Hello World: version 1.6.5")
        _SorcererHouse1BuildingZone = { Polygon = polygon.createRectangle( {4, 4} ) } 
    else
        Sorcerer:log("Hello World: version 1.6.6")
        _SorcererHouse1BuildingZone = { ZoneEntryList = {
            { Polygon = polygon.createRectangle( {4, 4} ),
              Type = { DEFAULT = true, NAVIGABLE = false, GRASS_CLEAR = true } }
        }}
   end
end

Sorcerer:register(myMonument)

-- Register the sorcerer house part
Sorcerer:register({
	DataType = "BUILDING_PART",
	Id = _SorcererPrefix .. "_HOUSE_PART",
        BuildingZone = _SorcererHouse1BuildingZone,
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
		CoreObjectPrefab = _SorcererPrefix .. "_HOUSE_PREFAB"
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	},
	AssetBuildingFunction = _SorcererPrefix .. "_HOUSE_FUNCTION"
})
Sorcerer:register({
		DataType = "BUILDING_FUNCTION_WORKPLACE",
                Id = _SorcererPrefix .. "_HOUSE_FUNCTION",
		WorkerCapacity = 1,
                RelatedJob = { Job = _SorcererPrefix, Behavior = SorcererTagBehaviorWork }
})

-- Register flag assigner component on the collider's type to 'PLATFORM'

Sorcerer:configurePrefabFlagList("models/sorcerer.fbx/Prefab/sorcerer/housePart", { "PLATFORM" })

-- Override building part components properties (generated by the building asset processor) to add building zones
Sorcerer:registerPrefabComponent("models/sorcerer.fbx/Prefab/sorcerer/housePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 4 }
})

Sorcerer:registerAssetId("models/sorcerer.fbx/Prefab/sorcerer/housePart/step_0/SmokeEmitter", _SorcererPrefix .. "_SMOKE_EMITTER_PREFAB")
Sorcerer:registerAssetId("models/sorcerer.fbx/Prefab/sorcerer/housePart/step_0/BatEmitter", _SorcererPrefix .. "_BAT_EMITTER_PREFAB")

Sorcerer:registerPrefabComponent("models/sorcerer.fbx/Prefab/sorcerer/housePart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZoneData = {DataType = "BUILDING_ZONE", Polygon = polygon.createRectangle({4,4})},
	FeedbackComponentListToActivate = {
                 { _SorcererPrefix .. "_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" },
                 { _SorcererPrefix .. "_BAT_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer.fbx/Prefab/sorcerer/housePart/step_0/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_BLACKSMITH_ROCK",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer.fbx/Prefab/sorcerer/housePart/step_0/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer.fbx/Prefab/sorcerer/housePart/step_0/BatEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "BAT_PARTICLE_SYSTEM",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer.fbx/Prefab/sorcerer/housePart/step_0/BatEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})
